@@ -5,6 +5,7 @@ from __future__ import annotations
 import logging
 import os
 import subprocess
+import sys
 
 import dvc.repo
 import git
@@ -19,7 +20,7 @@ logger.setLevel(logging.INFO)
 
 def configure_remote(wdir: str = None):
     try:
-        project_name = calkit.git.detect_project_name(path=wdir)
+        project_name = calkit.detect_project_name(wdir=wdir)
     except ValueError as e:
         raise ValueError(f"Can't detect project name: {e}")
     # If Git origin is not set, set that
@@ -40,11 +41,30 @@ def configure_remote(wdir: str = None):
     base_url = calkit.cloud.get_base_url()
     remote_url = f"{base_url}/projects/{project_name}/dvc"
     subprocess.check_call(
-        ["dvc", "remote", "add", "-d", "-f", get_app_name(), remote_url],
+        [
+            sys.executable,
+            "-m",
+            "dvc",
+            "remote",
+            "add",
+            "-d",
+            "-f",
+            get_app_name(),
+            remote_url,
+        ],
         cwd=wdir,
     )
     subprocess.check_call(
-        ["dvc", "remote", "modify", get_app_name(), "auth", "custom"],
+        [
+            sys.executable,
+            "-m",
+            "dvc",
+            "remote",
+            "modify",
+            get_app_name(),
+            "auth",
+            "custom",
+        ],
         cwd=wdir,
     )
 
@@ -95,8 +115,30 @@ def add_external_remote(owner_name: str, project_name: str) -> dict:
     base_url = calkit.cloud.get_base_url()
     remote_url = f"{base_url}/projects/{owner_name}/{project_name}/dvc"
     remote_name = f"{get_app_name()}:{owner_name}/{project_name}"
-    subprocess.call(["dvc", "remote", "add", "-f", remote_name, remote_url])
-    subprocess.call(["dvc", "remote", "modify", remote_name, "auth", "custom"])
+    subprocess.call(
+        [
+            sys.executable,
+            "-m",
+            "dvc",
+            "remote",
+            "add",
+            "-f",
+            remote_name,
+            remote_url,
+        ]
+    )
+    subprocess.call(
+        [
+            sys.executable,
+            "-m",
+            "dvc",
+            "remote",
+            "modify",
+            remote_name,
+            "auth",
+            "custom",
+        ]
+    )
     set_remote_auth(remote_name)
     return {"name": remote_name, "url": remote_url}
 
@@ -114,7 +156,9 @@ def get_remotes(wdir: str = None) -> dict[str, str]:
     value.
     """
     out = (
-        subprocess.check_output(["dvc", "remote", "list"], cwd=wdir)
+        subprocess.check_output(
+            [sys.executable, "-m", "dvc", "remote", "list"], cwd=wdir
+        )
         .decode()
         .strip()
     )
