@@ -7,6 +7,7 @@ import os
 import platform
 import re
 import subprocess
+import sys
 from typing import Literal
 
 import dvc
@@ -79,7 +80,7 @@ def get_root(get_jupyter_servers: bool = True) -> list[LocalProject]:
     for pdir in project_dirs:
         logger.info(f"Inspecting {pdir}")
         try:
-            project = calkit.git.detect_project_name(path=pdir)
+            project = calkit.detect_project_name(wdir=pdir)
         except ValueError:
             logger.warning(f"Can't detect project name in {pdir}")
             continue
@@ -218,7 +219,9 @@ def dvc_pull(owner_name: str, project_name: str) -> Message:
     logger.info(f"Looking for project {owner_name}/{project_name}")
     project = get_local_project(owner_name, project_name)
     logger.info(f"Found project at {project.wdir}")
-    subprocess.check_call(["dvc", "pull"], cwd=project.wdir)
+    subprocess.check_call(
+        [sys.executable, "-m", "dvc", "pull"], cwd=project.wdir
+    )
     return Message(message="Success!")
 
 
@@ -227,7 +230,9 @@ def dvc_push(owner_name: str, project_name: str) -> Message:
     logger.info(f"Looking for project {owner_name}/{project_name}")
     project = get_local_project(owner_name, project_name)
     logger.info(f"Found project at {project.wdir}")
-    subprocess.check_call(["dvc", "push"], cwd=project.wdir)
+    subprocess.check_call(
+        [sys.executable, "-m", "dvc", "push"], cwd=project.wdir
+    )
     return Message(message="Success!")
 
 
@@ -453,7 +458,8 @@ def discard_changes(owner_name: str, project_name: str) -> Message:
         for path in changed:
             logger.info(f"Checking out {path} with DVC")
             subprocess.check_call(
-                ["dvc", "checkout", path, "--force"], cwd=project.wdir
+                [sys.executable, "-m", "dvc", "checkout", path, "--force"],
+                cwd=project.wdir,
             )
     except dvc.config.ConfigError:
         pass
@@ -496,7 +502,7 @@ def get_pipeline(owner_name: str, project_name: str) -> Pipeline:
             raw_yaml = f.read()
         pipeline = calkit.ryaml.load(raw_yaml)
         mermaid = subprocess.check_output(
-            ["dvc", "dag", "--mermaid"], cwd=project.wdir
+            [sys.executable, "-m", "dvc", "dag", "--mermaid"], cwd=project.wdir
         ).decode()
         return Pipeline(
             raw_yaml=raw_yaml,
